@@ -34,13 +34,9 @@
 #endif
 
 #include <kaboutdata.h>
-#include <kdialog.h>
-#include <kglobal.h>
 #include <KLocalizedString>
 
-#include <QLayout>
 #include <QPushButton>
-#include <QTabWidget>
 #include <QTimer>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -92,7 +88,7 @@ KCMNic::KCMNic(QWidget *parent, const QVariantList &) :
 	KCModule(parent) {
 	QVBoxLayout *box=new QVBoxLayout(this);
 	box->setMargin(0);
-	box->setSpacing(KDialog::spacingHint());
+	//PORT QT5 box->setSpacing(KDialog::spacingHint());
 	m_list=new QTreeWidget(this);
 	m_list->setRootIsDecorated(false);
 	box->addWidget(m_list);
@@ -106,8 +102,8 @@ KCMNic::KCMNic(QWidget *parent, const QVariantList &) :
 	hbox->addStretch(1);
 	QTimer* timer=new QTimer(this);
 	timer->start(60000);
-	connect(m_updateButton, SIGNAL(clicked()), this, SLOT(update()));
-	connect(timer, SIGNAL(timeout()), this, SLOT(update()));
+	connect(m_updateButton, &QPushButton::clicked, this, &KCMNic::update);
+	connect(timer, &QTimer::timeout, this, &KCMNic::update);
 	update();
 	KAboutData *about = new KAboutData(i18n("kcminfo"),
 			i18n("System Information Control Module"),
