@@ -23,18 +23,14 @@
 #include <QLayout>
 #include <QPushButton>
 #include <QFile>
-#include <QTextStream>
 #include <QTreeWidgetItem>
 #include <QTreeWidget>
 #include <QVBoxLayout>
+#include <KLocalizedString>
 
-#include <kcomponentdata.h>
-#include <kdialog.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
+#include <KDialog>
 
 #include <sys/time.h>
 #include <sys/types.h>
@@ -44,6 +40,7 @@
 #include <string.h>
 
 #include <libraw1394/csr.h>
+#include <QStandardPaths>
 
 #define CONFIGROM_BASE 0x00
 #define CONFIGROM_CAP  0x08
@@ -94,8 +91,8 @@ View1394::View1394(QWidget *parent, const QVariantList &) :
 	*/
 	box->addWidget(m_view);
 	m_view->layout()->setMargin(0);
-	connect(m_view->m_busResetPb, SIGNAL(clicked()), this, SLOT(generateBusReset()));
-	connect(&m_rescanTimer, SIGNAL(timeout()), this, SLOT(rescanBus()));
+	connect(m_view->m_busResetPb, &QPushButton::clicked, this, &View1394::generateBusReset);
+	connect(&m_rescanTimer, &QTimer::timeout, this, &View1394::rescanBus);
 	rescanBus();
 }
 
@@ -192,7 +189,7 @@ void View1394::rescanBus() {
 		raw1394_set_userdata(handle, this);
 		raw1394_set_bus_reset_handler(handle, my_reset_handler);
 		QSocketNotifier *notif=new QSocketNotifier(raw1394_get_fd(handle),QSocketNotifier::Read);
-		connect(notif, SIGNAL(activated(int)), this, SLOT(callRaw1394EventLoop(int)));
+		connect(notif, &QSocketNotifier::activated, this, &View1394::callRaw1394EventLoop);
 		m_notifiers.append(notif);
 		m_handles.append(handle);
 
@@ -277,7 +274,7 @@ void View1394::generateBusReset() {
 }
 
 OuiDb::OuiDb() {
-	QString filename=KStandardDirs::locate("data", "kcmview1394/oui.db");
+	QString filename=QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kcmview1394/oui.db");
 	if (filename.isEmpty())
 		return;
 	QFile f(filename);
