@@ -36,6 +36,7 @@ KicApp::KicApp(int &argc, char **argv)
     : QApplication(argc, argv)
 {
     QApplication::setApplicationDisplayName(i18n("KDE Info Center"));
+    QApplication::setOrganizationDomain("kde.org");
     display = new KInfoCenter();
     display->show();
 
@@ -46,12 +47,11 @@ int main(int argc, char *argv[])
 {
     KLocalizedString::setApplicationDomain("kinfocenter");
 
-    KicApp Kic(argc, argv);
-
     KAboutData aboutData( QStringLiteral("kinfocenter"), i18n("KDE Info Center"),
         PROJECT_VERSION, i18n("The KDE Info Center"), KAboutLicense::GPL,
         i18n("(c) 2009-2010, The KDE SC KInfocenter Development Team"));
 
+    aboutData.setProgramIconName("hwinfo");
     aboutData.addAuthor(i18n("David Hubner"),i18n("Current Maintainer"), QStringLiteral("hubnerd@ntlworld.com"));
     aboutData.addAuthor(i18n("Helge Deller"), i18n("Previous Maintainer"), QStringLiteral("deller@kde.org"));
     aboutData.addAuthor(i18n("Matthias Hoelzer-Kluepfel"),QString(), QStringLiteral("hoelzer@kde.org"));
@@ -60,6 +60,8 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Waldo Bastian"), QString(), QStringLiteral("bastian@kde.org"));
     aboutData.addAuthor(i18n("Nicolas Ternisien"), QString(), QStringLiteral("nicolas.ternisien@gmail.com"));
     KAboutData::setApplicationData(aboutData);
+    KicApp Kic(argc, argv);
+
     QCommandLineParser parser;
     parser.addHelpOption();
     parser.addVersionOption();
